@@ -3,7 +3,7 @@ use 5.008_005;
 
 use Mouse::Exporter; # enables strict and warnings
 
-our $VERSION = 'v2.4.10';
+use version; our $VERSION = version->declare('v2.5.1');
 
 use Carp         ();
 use Scalar::Util ();
@@ -152,13 +152,15 @@ sub init_meta {
 1;
 __END__
 
+=for stopwords sartak MooseX MouseX aliasing codebase coderef deinitialization destructor invocant metaclass metaclass metaroles mro reftype reinitialize ro rw unimport wu-lee
+
 =head1 NAME
 
 Mouse - Moose minus the antlers
 
 =head1 VERSION
 
-This document describes Mouse version v2.4.10
+This document describes Mouse version v2.5.1
 
 =head1 SYNOPSIS
 
@@ -399,11 +401,19 @@ You may use L</extends> to replace the superclass list.
 Please unimport Mouse (C<no Mouse>) so that if someone calls one of the
 keywords (such as L</extends>) it will break loudly instead breaking subtly.
 
-=head1 SOURCE CODE ACCESS
+=head1 DEVELOPMENT
 
-We have a public git repository L<https://github.com/gfx/p5-Mouse>:.
+Here is the repo: L<https://github.com/gfx/p5-Mouse>.
 
-    git clone git://github.com/gfx/p5-Mouse.git
+You can build, test, and release it with B<Minilla>.
+
+    cpanm Minilla
+    minil build
+    minil test
+    minil release
+
+Note that F<Build.PL> and F<README.md> are generated by Minilla,
+so you should not edit them. Edit F<minil.toml> and F<lib/Mouse.pm> instead.
 
 =head1 SEE ALSO
 
@@ -440,8 +450,7 @@ with plenty of code borrowed from L<Class::MOP> and L<Moose>
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no exception.
-Please report any bugs to C<bug-mouse at rt.cpan.org>, or through the web
-interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Mouse>
+Please report any bugs to L<https://github.com/gfx/p5-Mouse/issues>.
 
 =head1 COPYRIGHT AND LICENSE
 
